
#ifndef KRDCCORE_EXPORT_H
#define KRDCCORE_EXPORT_H

#ifdef KRDCCORE_STATIC_DEFINE
#  define KRDCCORE_EXPORT
#  define KRDCCORE_NO_EXPORT
#else
#  ifndef KRDCCORE_EXPORT
#    ifdef krdccore_EXPORTS
        /* We are building this library */
#      define KRDCCORE_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KRDCCORE_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KRDCCORE_NO_EXPORT
#    define KRDCCORE_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KRDCCORE_DEPRECATED
#  define KRDCCORE_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KRDCCORE_DEPRECATED_EXPORT
#  define KRDCCORE_DEPRECATED_EXPORT KRDCCORE_EXPORT KRDCCORE_DEPRECATED
#endif

#ifndef KRDCCORE_DEPRECATED_NO_EXPORT
#  define KRDCCORE_DEPRECATED_NO_EXPORT KRDCCORE_NO_EXPORT KRDCCORE_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KRDCCORE_NO_DEPRECATED
#    define KRDCCORE_NO_DEPRECATED
#  endif
#endif

#endif /* KRDCCORE_EXPORT_H */
